@@ -11,6 +11,7 @@
 
 #include "Diagnostic.h"
 #include "StyleUtils.h"
+#include "VersionInfo.h"
 
 #include "dialogs/AboutDialog.h"
 #include "dialogs/FingerprintDialog.h"
@@ -32,7 +33,6 @@
 #include "Config.h"
 #endif
 
-#include <QApplication>
 #include <QDesktopServices>
 #include <QFileDialog>
 #include <QLocalServer>
@@ -79,18 +79,23 @@ MainWindow::MainWindow()
       m_actionQuit{new QAction(tr("&Quit"), this)},
       m_actionTrayQuit{new QAction(tr("&Quit"), this)},
       m_actionRestore{new QAction(tr("&Open Deskflow"), this)},
-      m_actionSettings{new QAction(tr("Preferences"), this)},
+      m_actionSettings{new QAction(tr("&Preferences"), this)},
       m_actionStartCore{new QAction(tr("&Start"), this)},
+      m_actionRestartCore{new QAction(tr("Rest&art"), this)},
       m_actionStopCore{new QAction(tr("S&top"), this)}
 {
-  const auto themeName = QStringLiteral("deskflow-%1").arg(iconMode());
-  if (QIcon::themeName().isEmpty())
-    QIcon::setThemeName(themeName);
-  else
-    QIcon::setFallbackThemeName(themeName);
-
   ui->setupUi(this);
 
+  setWindowIcon(QIcon::fromTheme(QStringLiteral("deskflow")));
+
+  // setup the log font
+  ui->textLog->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
+#ifdef Q_OS_MAC
+  auto f = ui->textLog->font();
+  f.setPixelSize(12);
+  ui->textLog->setFont(f);
+#endif
+
   // Setup Actions
   m_actionAbout->setText(tr("About %1...").arg(kAppName));
   m_actionAbout->setMenuRole(QAction::AboutRole);
@@ -116,6 +121,10 @@ MainWindow::MainWindow()
   m_actionStartCore->setShortcut(QKeySequence(tr("Ctrl+S")));
   m_actionStartCore->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
 
+  m_actionRestartCore->setVisible(false);
+  m_actionRestartCore->setShortcut(QKeySequence(tr("Ctrl+S")));
+  m_actionRestartCore->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+
   m_actionStopCore->setShortcut(QKeySequence(tr("Ctrl+T")));
   m_actionStopCore->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::ProcessStop));
 
@@ -146,14 +155,21 @@ MainWindow::MainWindow()
 
   // Force generation of SHA256 for the localhost
   if (Settings::value(Settings::Security::TlsEnabled).toBool()) {
+    if (Settings::value(Settings::Security::KeySize).toInt() < 2048) {
+      QMessageBox::information(
+          this, kAppName,
+          tr("Your current TLS key is smaller than the minimum allowed size, A new key 2048-bit key will be generated.")
+      );
+      regenerateLocalFingerprints();
+    }
     if (!QFile::exists(Settings::tlsLocalDb())) {
       regenerateLocalFingerprints();
       return;
     }
 
-    deskflow::FingerprintDatabase db;
-    db.read(Settings::tlsLocalDb().toStdString());
-    if (db.fingerprints().size() != kTlsDbSize) {
+    FingerprintDatabase db;
+    db.read(Settings::tlsLocalDb());
+    if (db.fingerprints().isEmpty()) {
       regenerateLocalFingerprints();
     }
   }
@@ -234,10 +250,11 @@ void MainWindow::setupControls()
   ui->lineEditName->setVisible(false);
 
 #if defined(Q_OS_MAC)
-
   ui->rbModeServer->setAttribute(Qt::WA_MacShowFocusRect, 0);
   ui->rbModeClient->setAttribute(Qt::WA_MacShowFocusRect, 0);
-
+  ui->btnSaveServerConfig->setFixedWidth(ui->btnSaveServerConfig->height());
+#else
+  ui->btnSaveServerConfig->setIconSize(QSize(22, 22));
 #endif
 
   const auto trayItemSize = QSize(24, 24);
@@ -278,17 +295,21 @@ void MainWindow::connectSlots()
 {
   connect(&Logger::instance(), &Logger::newLine, this, &MainWindow::handleLogLine);
 
-  connect(this, &MainWindow::shown, this, &MainWindow::firstShown, Qt::QueuedConnection);
-
   connect(Settings::instance(), &Settings::serverSettingsChanged, this, &MainWindow::serverConfigSaving);
   connect(Settings::instance(), &Settings::settingsChanged, this, &MainWindow::settingsChanged);
 
   connect(&m_coreProcess, &CoreProcess::starting, this, &MainWindow::coreProcessStarting, Qt::DirectConnection);
   connect(&m_coreProcess, &CoreProcess::error, this, &MainWindow::coreProcessError);
   connect(&m_coreProcess, &CoreProcess::logLine, this, &MainWindow::handleLogLine);
-  connect(&m_coreProcess, &CoreProcess::processStateChanged, this, &MainWindow::coreProcessStateChanged);
+  connect(
+      &m_coreProcess, &CoreProcess::processStateChanged, this, &MainWindow::coreProcessStateChanged,
+      Qt::QueuedConnection
+  );
   connect(&m_coreProcess, &CoreProcess::connectionStateChanged, this, &MainWindow::coreConnectionStateChanged);
   connect(&m_coreProcess, &CoreProcess::secureSocket, this, &MainWindow::secureSocket);
+  connect(
+      &m_coreProcess, &CoreProcess::daemonIpcClientConnectionFailed, this, &MainWindow::daemonIpcClientConnectionFailed
+  );
 
   connect(m_actionAbout, &QAction::triggered, this, &MainWindow::openAboutDialog);
   connect(m_actionClearSettings, &QAction::triggered, this, &MainWindow::clearSettings);
@@ -300,6 +321,7 @@ void MainWindow::connectSlots()
   connect(m_actionRestore, &QAction::triggered, this, &MainWindow::showAndActivate);
   connect(m_actionSettings, &QAction::triggered, this, &MainWindow::openSettings);
   connect(m_actionStartCore, &QAction::triggered, this, &MainWindow::startCore);
+  connect(m_actionRestartCore, &QAction::triggered, this, &MainWindow::resetCore);
   connect(m_actionStopCore, &QAction::triggered, this, &MainWindow::stopCore);
 
   connect(&m_versionChecker, &VersionChecker::updateFound, this, &MainWindow::versionCheckerUpdateFound);
@@ -310,16 +332,17 @@ void MainWindow::connectSlots()
 #endif
 
   connect(&m_serverConnection, &ServerConnection::configureClient, this, &MainWindow::serverConnectionConfigureClient);
+  connect(&m_serverConnection, &ServerConnection::clientsChanged, this, &MainWindow::serverClientsChanged);
 
   connect(&m_serverConnection, &ServerConnection::messageShowing, this, &MainWindow::showAndActivate);
   connect(&m_clientConnection, &ClientConnection::messageShowing, this, &MainWindow::showAndActivate);
 
   connect(ui->btnToggleCore, &QPushButton::clicked, m_actionStartCore, &QAction::trigger, Qt::UniqueConnection);
-  connect(ui->btnApplySettings, &QPushButton::clicked, this, &MainWindow::resetCore);
+  connect(ui->btnRestartCore, &QPushButton::clicked, this, &MainWindow::resetCore);
   connect(ui->btnConnect, &QPushButton::clicked, this, &MainWindow::resetCore);
 
   connect(ui->lineHostname, &QLineEdit::returnPressed, ui->btnConnect, &QPushButton::click);
-  connect(ui->lineHostname, &QLineEdit::textChanged, &m_coreProcess, &deskflow::gui::CoreProcess::setAddress);
+  connect(ui->lineHostname, &QLineEdit::textChanged, this, &MainWindow::remoteHostChanged);
 
   connect(ui->btnSaveServerConfig, &QPushButton::clicked, this, &MainWindow::saveServerConfig);
   connect(ui->btnConfigureServer, &QPushButton::clicked, this, [this] { showConfigureServer(""); });
@@ -354,19 +377,6 @@ void MainWindow::toggleLogVisible(bool visible)
   QTimer::singleShot(15, this, &MainWindow::updateSize);
 }
 
-void MainWindow::firstShown()
-{
-  // if a critical error was shown just before the main window (i.e. on app
-  // load), it will be hidden behind the main window. therefore we need to raise
-  // it up in front of the main window.
-  // HACK: because the `onShown` event happens just as the window is shown, the
-  // message box has a chance of being raised under the main window. to solve
-  // this we delay the error dialog raise by a split second. this seems a bit
-  // hacky and fragile, so maybe there's a better approach.
-  const auto kCriticalDialogDelay = 100;
-  QTimer::singleShot(kCriticalDialogDelay, this, &messages::raiseCriticalDialog);
-}
-
 void MainWindow::settingsChanged(const QString &key)
 {
   if (key == Settings::Log::Level) {
@@ -379,8 +389,7 @@ void MainWindow::settingsChanged(const QString &key)
 
   if ((key == Settings::Security::Certificate) || (key == Settings::Security::KeySize) ||
       (key == Settings::Security::TlsEnabled) || (key == Settings::Security::CheckPeers)) {
-    const auto certificate = Settings::value(Settings::Security::Certificate).toString();
-    if (m_tlsUtility.isEnabled() && !QFile::exists(certificate)) {
+    if (m_tlsUtility.isEnabled() && !QFile::exists(Settings::value(Settings::Security::Certificate).toString())) {
       m_tlsUtility.generateCertificate();
     }
     updateSecurityIcon(m_lblSecurityStatus->isVisible());
@@ -427,12 +436,16 @@ void MainWindow::startCore()
 {
   m_clientConnection.setShowMessage();
   m_coreProcess.start();
+  m_actionStartCore->setVisible(false);
+  m_actionRestartCore->setVisible(true);
 }
 
 void MainWindow::stopCore()
 {
   qDebug() << "stopping core process";
   m_coreProcess.stop();
+  m_actionStartCore->setVisible(true);
+  m_actionRestartCore->setVisible(false);
 }
 
 void MainWindow::clearSettings()
@@ -518,19 +531,23 @@ void MainWindow::showMyFingerprint()
     return;
   }
 
-  deskflow::FingerprintDatabase db;
-  db.read(Settings::tlsLocalDb().toStdString());
-  if (db.fingerprints().size() != kTlsDbSize) {
+  FingerprintDatabase db;
+  db.read(Settings::tlsLocalDb());
+  if (db.fingerprints().isEmpty()) {
     if (regenerateLocalFingerprints())
       showMyFingerprint();
     return;
   }
 
-  QList<deskflow::FingerprintData> fingerprints;
-  fingerprints.reserve(db.fingerprints().size());
-  std::copy(db.fingerprints().begin(), db.fingerprints().end(), std::back_inserter(fingerprints));
+  Fingerprint sha256Print;
+  for (const auto &f : std::as_const(db.fingerprints())) {
+    if (f.type == Fingerprint::Type::SHA256) {
+      sha256Print = f;
+      break;
+    }
+  }
 
-  FingerprintDialog fingerprintDialog(this, fingerprints);
+  FingerprintDialog fingerprintDialog(this, sha256Print);
   fingerprintDialog.exec();
 }
 
@@ -567,9 +584,10 @@ void MainWindow::updateModeControls(bool serverMode)
     if (!startedBefore && !m_coreProcess.isStarted()) {
       qDebug() << "auto-starting core server for first time";
       m_coreProcess.start();
-      messages::showFirstServerStartMessage(this);
     }
   }
+
+  toggleCanRunCore((!serverMode && !ui->lineHostname->text().isEmpty()) || serverMode);
 }
 
 void MainWindow::updateSecurityIcon(bool visible)
@@ -604,9 +622,19 @@ void MainWindow::serverConnectionConfigureClient(const QString &clientName)
 
 void MainWindow::open()
 {
+  Settings::value(Settings::Gui::Autohide).toBool() ? hide() : showAndActivate();
+
+  // if a critical error was shown just before the main window (i.e. on app
+  // load), it will be hidden behind the main window. therefore we need to raise
+  // it up in front of the main window.
+  // HACK: because the `onShown` event happens just as the window is shown, the
+  // message box has a chance of being raised under the main window. to solve
+  // this we delay the error dialog raise by a split second. this seems a bit
+  // hacky and fragile, so maybe there's a better approach.
+  const auto kCriticalDialogDelay = 100;
+  QTimer::singleShot(kCriticalDialogDelay, this, &messages::raiseCriticalDialog);
 
   if (!Settings::value(Settings::Gui::AutoUpdateCheck).isValid()) {
-    showAndActivate();
     Settings::setValue(Settings::Gui::AutoUpdateCheck, messages::showUpdateCheckOption(this));
   }
 
@@ -616,13 +644,11 @@ void MainWindow::open()
     qDebug() << "update check disabled";
   }
 
-  m_coreProcess.applyLogLevel();
-
   if (Settings::value(Settings::Core::StartedBefore).toBool()) {
-    m_coreProcess.start();
+    if (ui->rbModeClient->isChecked() && ui->lineHostname->text().isEmpty())
+      return;
+    startCore();
   }
-
-  Settings::value(Settings::Gui::Autohide).toBool() ? hide() : showAndActivate();
 }
 
 void MainWindow::coreProcessStarting()
@@ -640,16 +666,17 @@ void MainWindow::setStatus(const QString &status)
 
 void MainWindow::createMenuBar()
 {
-  auto menuFile = new QMenu(tr("File"), this);
+  auto menuFile = new QMenu(tr("&File"), this);
   menuFile->addAction(m_actionStartCore);
+  menuFile->addAction(m_actionRestartCore);
   menuFile->addAction(m_actionStopCore);
   menuFile->addSeparator();
   menuFile->addAction(m_actionQuit);
 
-  auto menuEdit = new QMenu(tr("Edit"), this);
+  auto menuEdit = new QMenu(tr("&Edit"), this);
   menuEdit->addAction(m_actionSettings);
 
-  auto menuHelp = new QMenu(tr("Help"), this);
+  auto menuHelp = new QMenu(tr("&Help"), this);
   menuHelp->addAction(m_actionAbout);
   menuHelp->addAction(m_actionReportBug);
   menuHelp->addSeparator();
@@ -666,7 +693,9 @@ void MainWindow::createMenuBar()
 void MainWindow::setupTrayIcon()
 {
   auto trayMenu = new QMenu(this);
-  trayMenu->addActions({m_actionStartCore, m_actionStopCore, m_actionMinimize, m_actionRestore, m_actionTrayQuit});
+  trayMenu->addActions(
+      {m_actionStartCore, m_actionRestartCore, m_actionStopCore, m_actionMinimize, m_actionRestore, m_actionTrayQuit}
+  );
   trayMenu->insertSeparator(m_actionMinimize);
   trayMenu->insertSeparator(m_actionTrayQuit);
   m_trayIcon->setContextMenu(trayMenu);
@@ -677,7 +706,8 @@ void MainWindow::setupTrayIcon()
 
 void MainWindow::applyConfig()
 {
-  ui->lineHostname->setText(Settings::value(Settings::Client::RemoteHost).toString());
+  if (!Settings::value(Settings::Client::RemoteHost).isNull())
+    ui->lineHostname->setText(Settings::value(Settings::Client::RemoteHost).toString());
   updateLocalFingerprint();
   setIcon();
 
@@ -688,14 +718,15 @@ void MainWindow::applyConfig()
   updateModeControls(coreMode == Settings::CoreMode::Server);
 }
 
-void MainWindow::saveSettings()
+void MainWindow::saveSettings() const
 {
   if (ui->rbModeClient->isChecked()) {
     Settings::setValue(Settings::Core::CoreMode, Settings::CoreMode::Client);
   } else if (ui->rbModeServer->isChecked()) {
     Settings::setValue(Settings::Core::CoreMode, Settings::CoreMode::Server);
   }
-  Settings::setValue(Settings::Client::RemoteHost, ui->lineHostname->text());
+  if (!ui->lineHostname->text().isEmpty())
+    Settings::setValue(Settings::Client::RemoteHost, ui->lineHostname->text());
   Settings::save();
 }
 
@@ -703,7 +734,6 @@ void MainWindow::setIcon()
 {
   // Using a theme icon that is packed in exe renders an invisible icon
   // Instead use the resource path of the packed icon
-  // TODO Report to Qt ref the bug here
   const bool symbolicIcon = Settings::value(Settings::Gui::SymbolicTrayIcon).toBool();
 #ifndef Q_OS_MAC
   QString iconString = QStringLiteral(":/icons/deskflow-%1/apps/64/deskflow").arg(iconMode());
@@ -730,9 +760,8 @@ void MainWindow::handleLogLine(const QString &line)
   int maxScroll = verticalScroll->maximum();
   const auto scrollAtBottom = qAbs(currentScroll - maxScroll) <= kScrollBottomThreshold;
 
-  // only trim end instead of the whole line to prevent tab-indented debug
-  // filenames from losing their indentation.
-  ui->textLog->appendPlainText(line.trimmed());
+  // Never trim the log line; doing so would hide underlying bugs where newlines and space is added unintentionally.
+  ui->textLog->appendPlainText(line);
 
   if (scrollAtBottom) {
     verticalScroll->setValue(verticalScroll->maximum());
@@ -759,33 +788,25 @@ void MainWindow::checkConnected(const QString &line)
 
 void MainWindow::checkFingerprint(const QString &line)
 {
-  static const QRegularExpression re(R"(.*peer fingerprint: \(SHA1\) ([A-F0-9:]+) \(SHA256\) ([A-F0-9:]+))");
-  auto match = re.match(line);
-  if (!match.hasMatch()) {
+  static const auto tlsPeerMessage = QStringLiteral("peer fingerprint: ");
+  static const qsizetype msgLen = QString(tlsPeerMessage).length();
+
+  const qsizetype midStart = line.indexOf(tlsPeerMessage);
+  if (midStart == -1)
     return;
-  }
 
-  const deskflow::FingerprintData sha1 = {
-      deskflow::fingerprintTypeToString(deskflow::FingerprintType::SHA1),
-      deskflow::string::fromHex(match.captured(1).toStdString())
-  };
+  const auto sha256Text = line.mid(midStart + msgLen).remove(':');
 
-  const auto sha256Text = match.captured(2);
-
-  const deskflow::FingerprintData sha256 = {
-      deskflow::fingerprintTypeToString(deskflow::FingerprintType::SHA256),
-      deskflow::string::fromHex(sha256Text.toStdString())
-  };
+  const Fingerprint sha256 = {Fingerprint::Type::SHA256, QByteArray::fromHex(sha256Text.toLatin1())};
 
   const bool isClient = m_coreProcess.mode() == CoreMode::Client;
-
   if ((isClient && m_checkedServers.contains(sha256Text)) || (!isClient && m_checkedClients.contains(sha256Text))) {
     qDebug("ignoring fingerprint, already handled");
     return;
   }
 
-  deskflow::FingerprintDatabase db;
-  db.read(trustedFingerprintDb().toStdString());
+  FingerprintDatabase db;
+  db.read(trustedFingerprintDatabase());
 
   if (db.isTrusted(sha256)) {
     qDebug("fingerprint is trusted");
@@ -801,12 +822,16 @@ void MainWindow::checkFingerprint(const QString &line)
 
   auto dialogMode = isClient ? FingerprintDialogMode::Client : FingerprintDialogMode::Server;
 
-  FingerprintDialog fingerprintDialog(this, {sha1, sha256}, dialogMode);
+  FingerprintDialog fingerprintDialog(this, sha256, dialogMode);
   connect(&fingerprintDialog, &FingerprintDialog::requestLocalPrintsDialog, this, &MainWindow::showMyFingerprint);
 
   if (fingerprintDialog.exec() == QDialog::Accepted) {
     db.addTrusted(sha256);
-    db.write(trustedFingerprintDb().toStdString());
+    if (!db.write(trustedFingerprintDatabase())) {
+      qCritical().noquote() << "unable to write fingerprint to db:" << trustedFingerprintDatabase();
+      m_coreProcess.stop();
+      return;
+    }
     if (isClient) {
       m_checkedServers.removeAll(sha256Text);
       m_coreProcess.start();
@@ -821,12 +846,6 @@ QString MainWindow::getTimeStamp() const
   return QStringLiteral("[%1]").arg(QDateTime::currentDateTime().toString(Qt::ISODate));
 }
 
-void MainWindow::showEvent(QShowEvent *event)
-{
-  QMainWindow::showEvent(event);
-  Q_EMIT shown();
-}
-
 void MainWindow::closeEvent(QCloseEvent *event)
 {
   if (Settings::value(Settings::Gui::CloseToTray).toBool() && event->spontaneous()) {
@@ -841,7 +860,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
   }
 
   if (m_saveOnExit) {
-    Settings::setValue(Settings::Gui::WindowGeometry, frameGeometry());
+    Settings::setValue(Settings::Gui::WindowGeometry, geometry());
   }
   qDebug() << "quitting application";
   event->accept();
@@ -866,6 +885,7 @@ void MainWindow::updateStatus()
 {
   const auto connection = m_coreProcess.connectionState();
   const auto process = m_coreProcess.processState();
+  const bool isServer = (m_coreProcess.mode() == CoreMode::Server);
 
   updateSecurityIcon(false);
   switch (process) {
@@ -892,7 +912,7 @@ void MainWindow::updateStatus()
       using enum CoreConnectionState;
 
     case Listening: {
-      if (m_coreProcess.mode() == CoreMode::Server) {
+      if (isServer) {
         updateSecurityIcon(true);
         setStatus(tr("%1 is waiting for clients").arg(kAppName));
       }
@@ -906,7 +926,10 @@ void MainWindow::updateStatus()
 
     case Connected: {
       updateSecurityIcon(true);
-      setStatus(tr("%1 is connected").arg(kAppName));
+      if (!isServer) {
+        setStatus(tr("%1 is connected as client of %2")
+                      .arg(kAppName, Settings::value(Settings::Client::RemoteHost).toString()));
+      }
       break;
     }
 
@@ -922,9 +945,12 @@ void MainWindow::coreProcessStateChanged(CoreProcessState state)
 {
   updateStatus();
 
-  if (state == CoreProcessState::Started) {
+  if (state == CoreProcessState::Started && !Settings::value(Settings::Core::StartedBefore).toBool()) {
     qDebug() << "recording that core has started";
     Settings::setValue(Settings::Core::StartedBefore, true);
+    if (m_coreProcess.mode() == CoreMode::Server) {
+      messages::showFirstServerStartMessage(this);
+    }
   }
 
   if (state == CoreProcessState::Started || state == CoreProcessState::Starting ||
@@ -935,9 +961,9 @@ void MainWindow::coreProcessStateChanged(CoreProcessState state)
     ui->btnToggleCore->setText(tr("&Stop"));
     ui->btnToggleCore->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::ProcessStop));
 
-    ui->btnApplySettings->setEnabled(true);
-
-    m_actionStartCore->setEnabled(false);
+    ui->btnRestartCore->setEnabled(true);
+    m_actionStartCore->setVisible(false);
+    m_actionRestartCore->setVisible(true);
     m_actionStopCore->setEnabled(true);
 
   } else {
@@ -947,9 +973,9 @@ void MainWindow::coreProcessStateChanged(CoreProcessState state)
     ui->btnToggleCore->setText(tr("&Start"));
     ui->btnToggleCore->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
 
-    ui->btnApplySettings->setEnabled(false);
-
-    m_actionStartCore->setEnabled(true);
+    ui->btnRestartCore->setEnabled(false);
+    m_actionStartCore->setVisible(true);
+    m_actionRestartCore->setVisible(false);
     m_actionStopCore->setEnabled(false);
   }
 }
@@ -1006,24 +1032,15 @@ void MainWindow::updateLocalFingerprint()
   m_btnFingerprint->setVisible(tlsEnabled && QFile::exists(Settings::tlsLocalDb()));
 }
 
-void MainWindow::autoAddScreen(const QString name)
+void MainWindow::autoAddScreen(const QString &name)
 {
+  if (name.isEmpty())
+    return;
 
-  int r = m_serverConfig.autoAddScreen(name);
-  if (r != kAutoAddScreenOk) {
-    switch (r) {
-    case kAutoAddScreenManualServer:
-      showConfigureServer(
-          tr("Please add the server (%1) to the grid.").arg(Settings::value(Settings::Core::ScreenName).toString())
-      );
-      break;
-
-    case kAutoAddScreenManualClient:
-      showConfigureServer(
-          tr("Please add the server (%1) to the grid.").arg(Settings::value(Settings::Core::ScreenName).toString())
-      );
-      break;
-    }
+  if (m_serverConfig.autoAddScreen(name) == AutoAddScreenManualClient) {
+    showConfigureServer(
+        tr("Please add the client (%1) to the grid.").arg(Settings::value(Settings::Core::ScreenName).toString())
+    );
   }
 }
 
@@ -1117,7 +1134,7 @@ void MainWindow::setHostName()
   applyConfig();
 }
 
-QString MainWindow::trustedFingerprintDb()
+QString MainWindow::trustedFingerprintDatabase() const
 {
   const bool isClient = m_coreProcess.mode() == CoreMode::Client;
   return isClient ? Settings::tlsTrustedServersDb() : Settings::tlsTrustedClientsDb();
@@ -1130,11 +1147,66 @@ bool MainWindow::regenerateLocalFingerprints()
     return false;
   }
 
-  TlsCertificate tls;
-  if (!tls.generateFingerprint(certificate)) {
+  if (TlsCertificate tls; !tls.generateFingerprint(certificate)) {
     return false;
   }
 
   updateLocalFingerprint();
   return true;
 }
+
+void MainWindow::serverClientsChanged(const QStringList &clients)
+{
+  if (m_coreProcess.mode() != CoreMode::Server || !m_coreProcess.isStarted())
+    return;
+
+  switch (clients.size()) {
+  case 0:
+    setStatus(tr("%1 is waiting for clients").arg(kAppName));
+    ui->statusBar->setToolTip("");
+    break;
+
+  case 1:
+    setStatus(tr("%1 is connected to a client: %2").arg(kAppName, clients.first()));
+    ui->statusBar->setToolTip("");
+    break;
+
+  case 2:
+  case 3:
+  case 4:
+    setStatus(
+        tr("%1 is connected, with %2 clients: %3").arg(kAppName, QString::number(clients.size()), clients.join(", "))
+    );
+    ui->statusBar->setToolTip(tr("Clients:\n %1").arg(clients.join("\n")));
+    break;
+  default:
+    setStatus(tr("%1 is connected, with %n client(s)", "", clients.size()).arg(kAppName));
+    ui->statusBar->setToolTip(tr("Clients:\n  %1").arg(clients.join("\n")));
+    break;
+  }
+}
+
+void MainWindow::daemonIpcClientConnectionFailed()
+{
+  if (deskflow::gui::messages::showDaemonOffline(this)) {
+    m_coreProcess.retryDaemon();
+  }
+}
+
+void MainWindow::toggleCanRunCore(bool enableButtons)
+{
+  ui->btnToggleCore->setEnabled(enableButtons);
+  ui->btnConnect->setEnabled(enableButtons);
+  ui->btnRestartCore->setEnabled(enableButtons && m_coreProcess.isStarted());
+  m_actionStartCore->setEnabled(enableButtons);
+  m_actionStopCore->setEnabled(enableButtons);
+}
+
+void MainWindow::remoteHostChanged(const QString &newRemoteHost)
+{
+  m_coreProcess.setAddress(newRemoteHost);
+  toggleCanRunCore(!newRemoteHost.isEmpty() && ui->rbModeClient->isChecked());
+  if (newRemoteHost.isEmpty()) {
+    Settings::setValue(Settings::Client::RemoteHost, QVariant());
+  }
+}
