@@ -20,12 +20,12 @@ class SecureListenSocket : public TCPListenSocket
 {
 public:
   SecureListenSocket(
-      IEventQueue *events, SocketMultiplexer *socketMultiplexer, IArchNetwork::EAddressFamily family,
+      IEventQueue *events, SocketMultiplexer *socketMultiplexer, IArchNetwork::AddressFamily family,
       SecurityLevel securityLevel = SecurityLevel::PlainText
   );
 
   // IListenSocket overrides
-  virtual IDataSocket *accept();
+  std::unique_ptr<IDataSocket> accept() override;
 
 private:
   const SecurityLevel m_securityLevel;
